==> opensubdiv-3.3.1-1-armv7h.pkg.tar.xz: usr/share/doc/opensubdiv/doxy_html/a00714.js <==
var a00714 =
[
    [ "AdaptiveOptions", "a00722.html", "a00722" ],
    [ "UniformOptions", "a00718.html", "a00718" ],
    [ "TopologyRefiner", "a00714.html#a91353962838bff64448014136e0e11ff", null ],
    [ "~TopologyRefiner", "a00714.html#ad34359a8dc42748122362e459f1409aa", null ],
    [ "GetAdaptiveOptions", "a00714.html#af1cb63210dc03f27cbdb15dc4d3c48b6", null ],
    [ "GetFVarLinearInterpolation", "a00714.html#af29a7e9914ee6860c7167300ea17e514", null ],
    [ "GetLevel", "a00714.html#ad2dfb3b5ee4cae694d7760da4f28d2fd", null ],
    [ "getLevel", "a00714.html#a2d36c2460381477ff285c334874f92b7", null ],
    [ "getLevel", "a00714.html#a1bfd77fdb60545a6cc34ac83cd6da40f", null ],
    [ "GetMaxLevel", "a00714.html#a7d0b5dc6f7f567507a906e00d1887151", null ],
    [ "GetMaxValence", "a00714.html#a14bf987459715b918b370247bb24a61c", null ],
    [ "GetNumEdgesTotal", "a00714.html#a96f712a5e40873f00b0b61f72ffb9e3c", null ],
    [ "GetNumFacesTotal", "a00714.html#ac5eadebfdd9b11ac383653e5a2383231", null ],
    [ "GetNumFaceVerticesTotal", "a00714.html#accbb5f2a2fa9138df8c399b9f1d37982", null ],
    [ "GetNumFVarChannels", "a00714.html#aa9be824a572029f3ec1e0c0d6cfecd77", null ],
    [ "GetNumFVarValuesTotal", "a00714.html#a30e986821916537de9d85e6b032ff5da", null ],
    [ "GetNumLevels", "a00714.html#a239ca467443788cab395336ec33c7dbe", null ],
    [ "GetNumVerticesTotal", "a00714.html#ae8ef99a47f8185a3a621e4d5b10a20a0", null ],
    [ "getRefinement", "a00714.html#ab88e1247a712bb4af838e6ae92b6100b", null ],
    [ "getRefinement", "a00714.html#a3ee96a3a8dc4dcfaedc4b1637c15f506", null ],
    [ "GetSchemeOptions", "a00714.html#a4528f38657b0c96bce6c3d7deffd7c02", null ],
    [ "GetSchemeType", "a00714.html#a758e06255013d2d7393c3ac2d18f6922", null ],
    [ "GetUniformOptions", "a00714.html#abb1241288f333733e84a5676f55f6bb9", null ],
    [ "HasHoles", "a00714.html#a1b68f0501aabb94ba410e006181d2cc5", null ],
    [ "IsUniform", "a00714.html#a5dfa6810f510fac1ec621fc9e6b530c4", null ],
    [ "RefineAdaptive", "a00714.html#adc05db2d92b02e349e1c305cd9ef5361", null ],
    [ "RefineUniform", "a00714.html#ad22b7ffd9f8f3b488e5f220cf00c8c82", null ],
    [ "Unrefine", "a00714.html#ae93be3ade4e67999007460900bbbe039", null ],
    [ "EndCapGregoryBasisPatchFactory", "a00714.html#a91bd526bed70df47a4ff3b804de3ef34", null ],
    [ "EndCapLegacyGregoryPatchFactory", "a00714.html#a3709c85092d8b84606ab484d22372f11", null ],
    [ "PatchTableFactory", "a00714.html#a96b515483261203fd97a17bf37f72594", null ],
    [ "PrimvarRefiner", "a00714.html#ad8e04e25ce10ef425ec5478a37ae7552", null ],
    [ "PtexIndices", "a00714.html#a3e6c896f40ac50aec4b28f19bc4eae9c", null ],
    [ "TopologyRefinerFactory", "a00714.html#a7efec9ae15b61001dcf6a0de284914b7", null ],
    [ "TopologyRefinerFactoryBase", "a00714.html#a7b09fef2ae2989a546c50a65add2091f", null ]
];

==> opensubdiv-3.3.3-1-armv7h.pkg.tar.xz: usr/share/doc/opensubdiv/doxy_html/a00714.js <==
var a00714 =
[
    [ "AdaptiveOptions", "a00722.html", "a00722" ],
    [ "UniformOptions", "a00718.html", "a00718" ],
    [ "TopologyRefiner", "a00714.html#a91353962838bff64448014136e0e11ff", null ],
    [ "~TopologyRefiner", "a00714.html#ad34359a8dc42748122362e459f1409aa", null ],
    [ "GetAdaptiveOptions", "a00714.html#af1cb63210dc03f27cbdb15dc4d3c48b6", null ],
    [ "GetFVarLinearInterpolation", "a00714.html#af29a7e9914ee6860c7167300ea17e514", null ],
    [ "GetLevel", "a00714.html#ad2dfb3b5ee4cae694d7760da4f28d2fd", null ],
    [ "getLevel", "a00714.html#a2d36c2460381477ff285c334874f92b7", null ],
    [ "getLevel", "a00714.html#a1bfd77fdb60545a6cc34ac83cd6da40f", null ],
    [ "GetMaxLevel", "a00714.html#a7d0b5dc6f7f567507a906e00d1887151", null ],
    [ "GetMaxValence", "a00714.html#a14bf987459715b918b370247bb24a61c", null ],
    [ "GetNumEdgesTotal", "a00714.html#a96f712a5e40873f00b0b61f72ffb9e3c", null ],
    [ "GetNumFacesTotal", "a00714.html#ac5eadebfdd9b11ac383653e5a2383231", null ],
    [ "GetNumFaceVerticesTotal", "a00714.html#accbb5f2a2fa9138df8c399b9f1d37982", null ],
    [ "GetNumFVarChannels", "a00714.html#aa9be824a572029f3ec1e0c0d6cfecd77", null ],
    [ "GetNumFVarValuesTotal", "a00714.html#a30e986821916537de9d85e6b032ff5da", null ],
    [ "GetNumLevels", "a00714.html#a239ca467443788cab395336ec33c7dbe", null ],
    [ "GetNumVerticesTotal", "a00714.html#ae8ef99a47f8185a3a621e4d5b10a20a0", null ],
    [ "getRefinement", "a00714.html#ab88e1247a712bb4af838e6ae92b6100b", null ],
    [ "getRefinement", "a00714.html#a3ee96a3a8dc4dcfaedc4b1637c15f506", null ],
    [ "GetSchemeOptions", "a00714.html#a4528f38657b0c96bce6c3d7deffd7c02", null ],
    [ "GetSchemeType", "a00714.html#a758e06255013d2d7393c3ac2d18f6922", null ],
    [ "GetUniformOptions", "a00714.html#abb1241288f333733e84a5676f55f6bb9", null ],
    [ "HasHoles", "a00714.html#a1b68f0501aabb94ba410e006181d2cc5", null ],
    [ "IsUniform", "a00714.html#a5dfa6810f510fac1ec621fc9e6b530c4", null ],
    [ "RefineAdaptive", "a00714.html#adc05db2d92b02e349e1c305cd9ef5361", null ],
    [ "RefineUniform", "a00714.html#ad22b7ffd9f8f3b488e5f220cf00c8c82", null ],
    [ "Unrefine", "a00714.html#ae93be3ade4e67999007460900bbbe039", null ],
    [ "PatchBuilder", "a00714.html#a97612a1a955f8b65e6d7e7761ed1cef7", null ],
    [ "PatchTableBuilder", "a00714.html#ad452cef79832abb71eef0c3d88acc1a0", null ],
    [ "PrimvarRefiner", "a00714.html#ad8e04e25ce10ef425ec5478a37ae7552", null ],
    [ "PtexIndices", "a00714.html#a3e6c896f40ac50aec4b28f19bc4eae9c", null ],
    [ "TopologyRefinerFactory", "a00714.html#a7efec9ae15b61001dcf6a0de284914b7", null ],
    [ "TopologyRefinerFactoryBase", "a00714.html#a7b09fef2ae2989a546c50a65add2091f", null ]
];
